%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Technical Note TN111
% Parameters for 'Field-oriented control (FOC) of a PMSM'
% Copyright imperix ltd, 2021
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% =================== System parameters ======================== %%

ControlFreq    = 20e3;           % Control interrupt frequency [Hz]
ControlPeriod  = 1/ControlFreq;  % Control interrupt period [s]
SamplingPeriod = ControlPeriod;  % Sampling period [s]

Ipmsm.Ts = ControlPeriod;        % Current controller control period [s]

% Deadtime
dt = 1e-6;


%% =================== Plant model ======================== %%

% PMSM
Pmsm.p = 3;				% pole pairs [-]
Pmsm.Usn = 460;			% rated voltage [V]
Pmsm.Isn = 2.43;		% rated current [Arms]
Pmsm.fsn = 50;			% rated frequency [Hz]
Pmsm.wsn = 2*pi*50;		% rated angular frequency [rad/s]
Pmsm.Rs = 3.4;			% stator resistance [Ohm]
Pmsm.Ls = 12.15e-3;		% stator inductance [H]
Pmsm.Ld = Pmsm.Ls;
Pmsm.Lq = Pmsm.Ls;

Pmsm.Jm = 2.9e-4;		% moment of inertia [Nm^2]
Pmsm.kF = 0.0003035;	% friction coefficient 
Pmsm.Phi_pm = 0.25;		% flux from permanent magnets [Nm/Apeak]

Pmsm.Temn = 3.9; 		% nominal torque [Nm]
Pmsm.Pn = 1.23e3;		% nominal active power [W]

Pmsm.Is_max = 8.1;		% [A] peak current
Pmsm.Wm_Max = 4800;		% [rpm]

% Encoder parameters
PPR = 4096;             % Encoder pulses per turn [-]


%% ============== DC link - Voltage control =============== %%

% Breaking chopper
DcLink.Rbr = 50;		% 2kW
DcLink.Vdc0 = 600;      % [V]


%% =============== PMSM - Current control ================= %%

% Plant model
Ipmsm.K1 = 1 / Pmsm.Rs;
Ipmsm.T1 = Pmsm.Ld / Pmsm.Rs;
Ipmsm.K2 = 1 / Pmsm.Rs;
Ipmsm.T2 = Pmsm.Lq / Pmsm.Rs;

% Small time constants
Ipmsm.Tctrl = 0.5 * Ipmsm.Ts;			% Control delay [s]
Ipmsm.Tpwm = 0.5 * ControlPeriod;		% Modulator delay [s]
Ipmsm.Tsens = 0;                        % No filter used, ideal sensor
% Ipmsm.Tsens = 1 / (2*pi*1.6e3);		% Sensing delay (if LPF on ADC) [s]

Ipmsm.Kcm = 1;
Ipmsm.Ttot = Ipmsm.Tctrl + Ipmsm.Tpwm + Ipmsm.Tsens;

% Magnitude optimum
Ipmsm.Tn_d = Ipmsm.T1;
Ipmsm.Ti_d = 2 * Ipmsm.Kcm * Ipmsm.K1 * Ipmsm.Ttot;
Ipmsm.Tn_q = Ipmsm.T2;
Ipmsm.Ti_q = 2 * Ipmsm.Kcm * Ipmsm.K2 * Ipmsm.Ttot;

Ipmsm.Kp_d = Ipmsm.Tn_d / Ipmsm.Ti_d;
Ipmsm.Ki_d = 1 / Ipmsm.Ti_d;
Ipmsm.Kp_q = Ipmsm.Tn_q / Ipmsm.Ti_q;
Ipmsm.Ki_q = 1 / Ipmsm.Ti_q;

